/**
 * Copyright (c) 2001-2007 by PDFTron Systems Incorporated. All Rights Reserved.
 * Please Consult legal.txt and license.pdf regarding legal and license information.
 */
#ifndef   H_PDF2SVGAPI
#define   H_PDF2SVGAPI

/** 
 * The calling convention to use for all calls across the "library boundary."
 */
#ifdef _WIN32
  #define PDF2SVG_API_CALL __stdcall

  #ifdef PDF2SVG_API_EXPORT
    #define PDF2SVG_API(type) __declspec(dllexport) type PDF2SVG_API_CALL 
  #else
    #define PDF2SVG_API(type) __declspec(dllimport) type PDF2SVG_API_CALL 
  #endif
#else
  #define PDF2SVG_API_CALL 
  #define PDF2SVG_API(type) type
#endif

#ifdef __cplusplus
extern "C" {
#endif

/** 
 * 'mode' identifier passed in PDF2SVGCallback.
 * The 'mode' can be used to determine whether a message is an error or 
 * a progress message.
 */ 
#define PDF2SVG_ERROR		 1 /* Show the error message		*/
#define PDF2SVG_MSG			 2 /* Report the message			*/
#define PDF2SVG_GETPASS		 3 /* Get the password				*/
#define PDF2SVG_OUT_FILENAME 4 /* Reports the Saved File Names	*/

typedef char* PDF2SVG_API_CALL PDF2SVGCallback(int mode, char* msg, void* user_data);

/**
 * Initialize PDF2SVG with registration and license information.
 * Although PDF2SVGInit is typically called only once (e.g. during the program 
 * startup), it can also be called multiple times without side effects. 
 *
 * The first parameter is your username, the second parameter is your company name, 
 * and the last parameter is the license key supplied with your registration information.
 */

PDF2SVG_API(int)
PDF2SVGInit(char* user_name, char* company, char* license_key, char* resource_path);

/** 
 * Return codes for PDF2SVGRun function.
 */ 
#define PDF2SVG_OK             0  /* No errors */
#define PDF2SVG_ERR            1  /* Unspecified error */
#define PDF2SVG_ERR_BADKEY     2  /* Bad license key */
#define PDF2SVG_ERR_DIRCREATE  3  /* Failed to create the output directory */
#define PDF2SVG_ERR_READINGPDF 4  /* Failed to read input document */
#define PDF2SVG_ERR_PASSWORD   5  /* The password required to open PDF is incorrect */
#define PDF2SVG_ERR_CONVERT    6  /* A conversion error */


/**
 * Execute PDF2SVG command string.
 * 
 * PDF2SVGRun can be called multiple times to process PDF documents or folders 
 * with PDF documents. The function is completely thread safe, so it is possible to 
 * run many PDF2SVG threads at the same time.
 * 
 * @param command_str PDF2SVG command string. For a detailed explanation of 
 * all options and syntax, please refer to section 4 in PDF2SVG SDK Manual. 
 *
 * @param funct (optional) a pointer to the callback function used to report error 
 * as well as other messages. 
 *
 * @param user_data (optional) a pointer to custom data that you may want to 
 * pass to the callback function. NULL if you don't need to pass custom data.
 *
 * @return error code. A non-zero value indicates that an error was encountered.
 */
PDF2SVG_API(int)
PDF2SVGRun(char* command_str, PDF2SVGCallback* funct, void* user_data);

#ifdef __cplusplus
}
#endif

#endif  /* H_PDF2SVGAPI */
